@@ -49,19 +49,9 @@ sub dump {
 
 1;
 
-__END__
-
-=pod
-
-=encoding UTF-8
-
 =head1 NAME
 
-Acme::Coinbase::Config
-
-=head1 VERSION
-
-version 0.007
+Acme::Coinbase::Config -- read a acmecoinbase config file
 
 =head1 SYNOPSIS
 
@@ -75,10 +65,6 @@ Example of a usage goes here, such as
 
 Manages reading a config file.
 
-=head1 NAME
-
-Acme::Coinbase::Config -- read a acmecoinbase config file
-
 =head1 METHODS
 
 =over 4
@@ -99,21 +85,11 @@ reads the given parameter from the given section.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014 Josh Rabinowitz, All Rights Reserved.
+Copyright (c) 2018 Josh Rabinowitz, All Rights Reserved.
 
 =head1 AUTHORS
 
 Josh Rabinowitz
 
-=head1 AUTHOR
+=cut    
 
-joshr <joshr>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2014 by joshr.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
